aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorlloyd <[email protected]>2008-09-07 19:05:14 +0000
committerlloyd <[email protected]>2008-09-07 19:05:14 +0000
commit671f27d71b5587aa0e07516dd08a007aa53e4ea4 (patch)
tree3873b4720f278f7d849687bf964b68b42e632c11 /include
parentd21ec372e108efecf704b51bb2080dcacce854d2 (diff)
Remove bigint_mul_add_words. It was only used now in two callers,
bigint_simple_mul and bigint_simple_sqr. Examining these functions made it clear inlining would be beneficial, so these two functions have been moved from an anonymous namespace into mp_mulop.cpp (to allow assembly versions).
Diffstat (limited to 'include')
-rw-r--r--include/mp_core.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/include/mp_core.h b/include/mp_core.h
index 9df4a41e4..7ec0d0c49 100644
--- a/include/mp_core.h
+++ b/include/mp_core.h
@@ -38,10 +38,15 @@ void bigint_shr1(word[], u32bit, u32bit, u32bit);
void bigint_shr2(word[], const word[], u32bit, u32bit, u32bit);
/*************************************************
* Multiplication and Squaring Operations *
*************************************************/
-word bigint_mul_add_words(word[], const word[], u32bit, word);
+void bigint_simple_mul(word z[], const word x[], u32bit x_size,
+ const word y[], u32bit y_size);
+void bigint_simple_sqr(word z[], const word x[], u32bit x_size);
+/*************************************************
+* Linear Multiply *
+*************************************************/
void bigint_linmul2(word[], u32bit, word);
void bigint_linmul3(word[], const word[], u32bit, word);
void bigint_linmul_add(word[], u32bit, const word[], u32bit, word);
@@ -38,10 +38,15 @@ void bigint_shr1(word[], u32bit, u32bit, u32bit);
void bigint_shr2(word[], const word[], u32bit, u32bit, u32bit);
/*************************************************
-* Multiplication and Squaring Operations *
+* Simple O(N^2) Multiplication and Squaring *
*************************************************/